antares.apps.message.migrations package
=======================================

Submodules
----------

antares.apps.message.migrations.0001\_initial module
----------------------------------------------------

.. automodule:: antares.apps.message.migrations.0001_initial
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.message.migrations.0002\_auto\_20180624\_1759 module
-----------------------------------------------------------------

.. automodule:: antares.apps.message.migrations.0002_auto_20180624_1759
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: antares.apps.message.migrations
   :members:
   :undoc-members:
   :show-inheritance:
